@@ -1,4 +1,4 @@
-use crate::{borrowed, borrowed::parse::SPACE, borrowed::Error, tree};
+use crate::{borrowed::parse::SPACE, borrowed::Error, tree};
 use bstr::{BStr, ByteSlice};
 use nom::{
     bytes::complete::{tag, take, take_while1, take_while_m_n},
@@ -19,21 +19,21 @@ pub struct Tree<'a> {
     pub entries: Vec<Entry<'a>>,
 }
 
-/// An element of a [`Tree`][Tree::entries]
+/// An element of a [`Tree`][Tree::entries].
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
 #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
 pub struct Entry<'a> {
-    /// The kind of object to which `oid` is pointing
+    /// The kind of object to which `oid` is pointing.
     pub mode: tree::Mode,
     /// The name of the file in the parent tree.
     pub filename: &'a BStr,
     /// The id of the object representing the entry.
     #[cfg_attr(feature = "serde1", serde(borrow))]
-    pub oid: borrowed::Id<'a>,
+    pub oid: &'a git_hash::oid,
 }
 
 impl<'a> Tree<'a> {
-    /// Deserialize a Tree from `data`
+    /// Deserialize a Tree from `data`.
     pub fn from_bytes(data: &'a [u8]) -> Result<Tree<'a>, Error> {
         parse(data).map(|(_, t)| t).map_err(Error::from)
     }
@@ -68,7 +68,7 @@ fn parse_entry(i: &[u8]) -> IResult<&[u8], Entry<'_>, Error> {
         Entry {
             mode,
             filename: filename.as_bstr(),
-            oid: borrowed::Id::try_from(oid).expect("we counted exactly 20 bytes"),
+            oid: git_hash::oid::try_from(oid).expect("we counted exactly 20 bytes"),
         },
     ))
 }
