@@ -5,7 +5,7 @@
 
 use bstr::{BStr, BString, ByteSlice};
 
-/// For convenience to allow using `bstr` without adding it to own cargo manifest
+/// For convenience to allow using `bstr` without adding it to own cargo manifest.
 pub use bstr;
 
 pub mod borrowed;
@@ -16,5 +16,3 @@ pub use types::{tree, Error, Kind, Sign, Time};
 
 ///
 pub mod commit;
-
-pub use git_hash::Kind as HashKind;
