@@ -1,6 +1,8 @@
 //! Mutable objects with each field being separately allocated and mutable.
 //!
 //! Owned objects are Commits, Trees, Blobs and Tags that can be mutated and serialized.
+//! They either created using object [construction][Object] or by [deserializing existing objects][crate::borrowed::Object::from_bytes()]
+//! and converting these [into owned copies][crate::borrowed::Object::into_owned()] for mutation.
 
 pub(crate) const NL: &[u8; 1] = b"\n";
 pub(crate) const SPACE: &[u8; 1] = b" ";
@@ -8,8 +10,6 @@ pub(crate) const SPACE: &[u8; 1] = b" ";
 mod convert;
 mod ser;
 
-pub use git_hash::owned::Digest as Id;
-
 mod tag;
 pub use tag::Tag;
 
@@ -27,12 +27,12 @@ mod blob {
     #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
     #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
     pub struct Blob {
-        /// The data itself
+        /// The data itself.
         pub data: Vec<u8>,
     }
 
     impl Blob {
-        /// Write the blobs data to `out` verbatim
+        /// Write the blobs data to `out` verbatim.
         pub fn write_to(&self, mut out: impl io::Write) -> io::Result<()> {
             out.write_all(&self.data)
         }
