@@ -15,9 +15,9 @@ quick_error! {
     }
 }
 
-impl Into<io::Error> for Error {
-    fn into(self) -> io::Error {
-        io::Error::new(io::ErrorKind::Other, self)
+impl From<Error> for io::Error {
+    fn from(other: Error) -> io::Error {
+        io::Error::new(io::ErrorKind::Other, other)
     }
 }
 
@@ -53,7 +53,7 @@ pub fn trusted_header_signature(name: &[u8], value: &owned::Signature, mut out:
     out.write_all(NL)
 }
 
-pub fn trusted_header_id(name: &[u8], value: &owned::Id, mut out: impl io::Write) -> io::Result<()> {
+pub fn trusted_header_id(name: &[u8], value: &git_hash::ObjectId, mut out: impl io::Write) -> io::Result<()> {
     out.write_all(name)?;
     out.write_all(&SPACE[..])?;
     value.write_hex_to(&mut out)?;
