@@ -1,10 +1,10 @@
-use crate::{owned, owned::SPACE, tree::Mode};
+use crate::{owned::SPACE, tree::Mode};
 use bstr::{BString, ByteSlice};
 use quick_error::quick_error;
 use std::io;
 
 quick_error! {
-    /// The Error used in [`Tree::write_to()`]
+    /// The Error used in [`Tree::write_to()`].
     #[derive(Debug)]
     #[allow(missing_docs)]
     pub enum Error {
@@ -32,12 +32,12 @@ pub struct Tree {
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
 #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
 pub struct Entry {
-    /// The kind of object to which `oid` is pointing
+    /// The kind of object to which `oid` is pointing to.
     pub mode: Mode,
     /// The name of the file in the parent tree.
     pub filename: BString,
     /// The id of the object representing the entry.
-    pub oid: owned::Id,
+    pub oid: git_hash::ObjectId,
 }
 
 /// Serialization
@@ -69,7 +69,7 @@ impl Tree {
             out.write_all(&filename)?;
             out.write_all(&[b'\0'])?;
 
-            out.write_all(&oid[..])?;
+            out.write_all(oid.as_bytes())?;
         }
         Ok(())
     }
